@@ -26,17 +26,15 @@
 #ifdef __cplusplus
 extern "C" {
 #pragma }
-#endif /* __cplusplus }*/
+#endif /* __cplusplus */
 
 #include <glib.h>
 #include "gmime-message.h"
-#include "gmime-part.h"
-#include "gmime-content-type.h"
-#include "gmime-param.h"
+#include "gmime-stream.h"
 
-GMimePart *g_mime_parser_construct_part (const gchar *in, guint inlen);
+GMimePart *g_mime_parser_construct_part (GMimeStream *stream);
 
-GMimeMessage *g_mime_parser_construct_message (const gchar *data, gboolean save_extra_headers);
+GMimeMessage *g_mime_parser_construct_message (GMimeStream *stream);
 
 #ifdef __cplusplus
 }
